#  Copyright 2020 Google LLC
#  Copyright 2020 EPAM Systems
#  Copyright 2020 Amazon
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

"""DAG for opaque ingestion."""

from datetime import timedelta

import airflow.utils.dates
from airflow import DAG
from airflow.operators.python_operator import PythonOperator
from operators.deprecated.update_status import UpdateStatusOperator

from libs.create_records import create_records  # isort:skip

default_args = {
    "owner": "Airflow",
    "depends_on_past": False,
    "start_date": airflow.utils.dates.days_ago(0),
    "email": ["airflow@example.com"],
    "email_on_failure": False,
    "email_on_retry": False,
    "retries": 0,
    "retry_delay": timedelta(minutes=5),
    "trigger_rule": "none_failed",
}

workflow_name = "Default_ingest"
dag = DAG(
    workflow_name,
    default_args=default_args,
    schedule_interval=timedelta(
        days=1))

update_status_running_op = UpdateStatusOperator(
    task_id="update_status_running_task",
    dag=dag
)

update_status_finished_op = UpdateStatusOperator(
    task_id="update_status_finished_task",
    dag=dag
)

create_records_op = PythonOperator(
    task_id="create_records",
    python_callable=create_records,
    provide_context=True,
    dag=dag
)

update_status_running_op >> create_records_op >> update_status_finished_op
